==> haskell-http-api-data-0.3.7.2-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.3.7.2
id: http-api-data-0.3.7.2-13uANAucr6PGwF7sI13Jz8
key: http-api-data-0.3.7.2-13uANAucr6PGwF7sI13Jz8
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.
    .
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
abi: 42271096c62b45f1a50a3d9d93cbc5f9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/http-api-data-0.3.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/http-api-data-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/http-api-data-0.3.7.2
hs-libraries: HShttp-api-data-0.3.7.2-13uANAucr6PGwF7sI13Jz8
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-9rrXZSTFIKACL1r4WeB8Up
    attoparsec-iso8601-1.0.0.0-2smVMqrH8DF6JYyI6kDbcD
    bytestring-0.10.8.2 containers-0.5.10.2
    hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    http-types-0.9.1-BD2l1Kzs7Ve6mp82UloTud
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz time-1.8.0.2
    time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
    uri-bytestring-0.3.1.0-JOqXOJTIM7o1S9OCzfioOB
    uuid-types-1.0.3-JapvjLAqkud1SmKDqn1RFA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-9rrXZSTFIKACL1r4WeB8Up=0f65d953ef6806e52476b2e8588d0370
             attoparsec-iso8601-1.0.0.0-2smVMqrH8DF6JYyI6kDbcD=4df70a03d7bd24ecfa0c16b49b5ad93e
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             http-types-0.9.1-BD2l1Kzs7Ve6mp82UloTud=1efefe4d9e28b8d4aa72d634a67d063f
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy=112a439dbb7402a620113b8ac6cc712d
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
             uri-bytestring-0.3.1.0-JOqXOJTIM7o1S9OCzfioOB=5625f5269d5737b9fdadda71ed7ba08d
             uuid-types-1.0.3-JapvjLAqkud1SmKDqn1RFA=62a3b877c4fb15cee02580bb3361e899
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.3.7.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.3.7.2
id: http-api-data-0.3.7.2-EdBVZ6biqyd48ZSY5Rr7sR
key: http-api-data-0.3.7.2-EdBVZ6biqyd48ZSY5Rr7sR
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.
    .
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
abi: 384e120ba09e92b8b6c888507533aa10
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/http-api-data-0.3.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/http-api-data-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/http-api-data-0.3.7.2
hs-libraries: HShttp-api-data-0.3.7.2-EdBVZ6biqyd48ZSY5Rr7sR
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4
    attoparsec-iso8601-1.0.0.0-73xBXVEn8AX2h997Gru2WT
    bytestring-0.10.8.2 containers-0.5.10.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz time-1.8.0.2
    time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
    uri-bytestring-0.3.1.1-GLOygbw1XJO9BMaub2Eqmz
    uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4=923ea4b48e3ff86a32743bf7d135ea3e
             attoparsec-iso8601-1.0.0.0-73xBXVEn8AX2h997Gru2WT=99dc869645c436237b5d7e63c08f87b9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             time-locale-compat-0.1.1.3-EeYCrKbfyeWLGJYmfXhrGy=112a439dbb7402a620113b8ac6cc712d
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
             uri-bytestring-0.3.1.1-GLOygbw1XJO9BMaub2Eqmz=dc86d4477e7feb673240263d2040caab
             uuid-types-1.0.3-7SGDQuL1CwqDmbty1Mwily=57ea9cee1932ecc182feef039579eb9f
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
